@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -1941,6 +1941,20 @@ sub _InstallHandling {
         );
     }
 
+    # parse sopm-file and show <PackageRequired> information
+    if ( $Structure{PackageRequired} ) {
+        $Data{PackageRequired} = $PackageObject->GetRequiredPackages(
+            Structure => \%Structure,
+        );
+    }
+
+    # parse sopm-file and show <ModuleRequired> information
+    if ( $Structure{ModuleRequired} ) {
+        $Data{ModuleRequired} = $PackageObject->GetRequiredModules(
+            Structure => \%Structure,
+        );
+    }
+
     my %Response = $PackageObject->AnalyzePackageFrameworkRequirements(
         Framework => $Structure{Framework},
         NoLog     => 1,
@@ -2106,6 +2120,20 @@ sub _UpgradeHandling {
         );
     }
 
+    # parse sopm-file and show <PackageRequired> information
+    if ( $Structure{PackageRequired} ) {
+        $Data{PackageRequired} = $PackageObject->GetRequiredPackages(
+            Structure => \%Structure,
+        );
+    }
+
+    # parse sopm-file and show <ModuleRequired> information
+    if ( $Structure{ModuleRequired} ) {
+        $Data{ModuleRequired} = $PackageObject->GetRequiredModules(
+            Structure => \%Structure,
+        );
+    }
+
     my %Response = $PackageObject->AnalyzePackageFrameworkRequirements(
         Framework => $Structure{Framework},
         NoLog     => 1,
