@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -1030,6 +1030,19 @@ sub Run {
         );
     }
 
+    # show only owned tickets if we have the filter
+    if ( $TicketSearchSummary{Owned} ) {
+        $LayoutObject->Block(
+            Name => 'ContentLargeTicketGenericFilterOwned',
+            Data => {
+                %Param,
+                %{ $Self->{Config} },
+                Name => $Self->{Name},
+                %{$Summary},
+            },
+        );
+    }
+
     # add page nav bar
     my $Total = $Summary->{ $Self->{Filter} } || 0;
 
@@ -2553,6 +2566,10 @@ sub _SearchParamsGet {
             OwnerIDs => $TicketSearch{OwnerIDs} // [ $Self->{UserID}, ],
             LockIDs  => [ $LockName2ID{lock}, $LockName2ID{tmp_lock} ],
         },
+        Owned => {
+            OwnerIDs => [ $Self->{UserID}, ],
+            LockIDs  => $TicketSearch{LockIDs} // undef,
+        },
         Watcher => {
             WatchUserIDs => [ $Self->{UserID}, ],
             LockIDs      => $TicketSearch{LockIDs} // undef,
