@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -189,6 +189,66 @@ sub Sync {
         return;
     }
 
+    # check if user needs to be in a group!
+    if ( $Self->{AccessAttr} && $Self->{GroupDN} ) {
+
+        # just in case for debug
+        if ( $Self->{Debug} > 0 ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'notice',
+                Message  => 'check for groupdn!',
+            );
+        }
+
+        # search if we're allowed to
+        my $Filter2 = '';
+        if ( $Self->{UserAttr} eq 'DN' ) {
+            $Filter2 = "($Self->{AccessAttr}=" . escape_filter_value($UserDN) . ')';
+        }
+        else {
+            $Filter2 = "($Self->{AccessAttr}=" . escape_filter_value( $Param{User} ) . ')';
+        }
+        my $Result2 = $LDAP->search(
+            base   => $Self->{GroupDN},
+            filter => $Filter2,
+            attrs  => ['1.1'],
+        );
+        if ( $Result2->code() ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Search failed! base='$Self->{GroupDN}', filter='$Filter2', "
+                    . $Result2->error(),
+            );
+
+            # take down session
+            $LDAP->unbind();
+            $LDAP->disconnect();
+            return;
+        }
+
+        # extract it
+        my $GroupDN = '';
+        for my $Entry ( $Result2->all_entries() ) {
+            $GroupDN = $Entry->dn();
+        }
+
+        # log if there is no LDAP entry
+        if ( !$GroupDN ) {
+
+            # failed login note
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'notice',
+                Message  => "User: $Param{User} sync failed, no LDAP group entry found"
+                    . "GroupDN='$Self->{GroupDN}', Filter='$Filter2'! (REMOTE_ADDR: $RemoteAddr).",
+            );
+
+            # take down session
+            $LDAP->unbind();
+            $LDAP->disconnect();
+            return;
+        }
+    }
+
     # get needed objects
     my $UserObject   = $Kernel::OM->Get('Kernel::System::User');
     my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
