@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -685,7 +685,7 @@ sub GetFieldSelections {
 
 =head2 CustomerIDList()
 
-return a list of with all known unique CustomerIDs of the registered customers users (no SearchTerm),
+return a list of all known unique CustomerIDs of the registered customer users (no SearchTerm),
 or a filtered list where the CustomerIDs must contain a search term.
 
     my @CustomerIDs = $CustomerUserObject->CustomerIDList(
