@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -124,6 +124,8 @@ Returns:
 sub Run {
     my ( $Self, %Param ) = @_;
 
+    my $StdAttachmentObject = $Kernel::OM->Get('Kernel::System::StdAttachment');
+
     # define a common message to output in case of any error
     my $CommonMessage = "Process: $Param{ProcessEntityID} Activity: $Param{ActivityEntityID}"
         . " Transition: $Param{TransitionEntityID}"
@@ -144,7 +146,11 @@ sub Run {
 
     # Convert DynamicField value to HTML string, see bug#14229.
     my $HTMLUtilsObject = $Kernel::OM->Get('Kernel::System::HTMLUtils');
-    if ( $Param{Config}->{Body} =~ /OTRS_TICKET_DynamicField_/ ) {
+    if (
+        defined $Param{Config}->{Body}
+        && $Param{Config}->{Body} =~ /OTRS_TICKET_DynamicField_/
+        )
+    {
         MATCH:
         for my $Match ( sort keys %{ $Param{Ticket} } ) {
             if ( $Match =~ m/DynamicField_(.*)/ && $Param{Ticket}->{$Match} ) {
@@ -323,11 +329,40 @@ sub Run {
             ChannelName => $Param{Config}->{CommunicationChannel},
         );
 
-        # check for selected Attachments
-        if ( $Param{Config}->{Attachments} ) {
+        # attachments
+        if ( $Param{Config}->{AttachmentsReuse} ) {
             $Param{Config}->{Attachment} = $Self->_GetAttachments(%Param);
         }
 
+        if ( $Param{Config}->{Attachments} || $Param{Config}->{AttachmentIDs} ) {
+            my @AttachmentIDs = split /\s*,\s*/, ( $Param{Config}->{AttachmentIDs} || '' );
+
+            my @AttachmentNames = split /\s*,\s*/, ( $Param{Config}->{Attachments} || '' );
+            ATTACHMENT:
+            for my $Name (@AttachmentNames) {
+                my $ID = $StdAttachmentObject->StdAttachmentLookup(
+                    StdAttachment => $Name,
+                );
+                next ATTACHMENT if !$ID;
+
+                push @AttachmentIDs, $ID;
+            }
+
+            ATTACHMENT:
+            for my $ID (@AttachmentIDs) {
+                my %Data = $StdAttachmentObject->StdAttachmentGet(
+                    ID => $ID,
+                );
+                next ATTACHMENT if !%Data;
+
+                push @{ $Param{Config}->{Attachment} }, {
+                    Content     => $Data{Content},
+                    ContentType => $Data{ContentType},
+                    Filename    => $Data{Filename},
+                };
+            }
+        }
+
         # Create article for the new ticket.
         $ArticleID = $ArticleBackendObject->ArticleCreate(
             %{ $Param{Config} },
