@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -108,7 +108,7 @@ Then you can use the full API of L<Selenium::Remote::Driver> on this object.
         },
     );
 
-    my $Selenium = $Kernel::OM->Get('Kernel::System::UnitTest::Selenium');
+    my $SeleniumObject = $Kernel::OM->Get('Kernel::System::UnitTest::Selenium');
 
 =cut
 
