@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -197,6 +197,17 @@ my @NeededModules = (
             zypper => 'perl-Authen-SASL',
         },
     },
+    {
+        Module    => 'CPAN::Audit',
+        Required  => 0,
+        Comment   => 'Scan CPAN dependencies in Kernel/cpan-lib and in the system for known vulnerabilities.',
+        InstTypes => {
+            aptget => 'libcpan-audit-perl',
+            emerge => '',
+            zypper => '',
+            ports  => '',
+        },
+    },
     {
         Module    => 'Crypt::Eksblowfish::Bcrypt',
         Required  => 0,
