@@ -1,6 +1,6 @@
 // --
 // Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-// Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+// Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (GPL). If you
@@ -71,6 +71,10 @@ Core.UI.RichTextEditor = (function (TargetNS) {
     function InitAutocompletion(Editor) {
         var AutocompletionSettings = {};
 
+        // CodeMirror does not load any other plugins, so the autocomplete plugin is not available then
+        if (Core.Config.Get('RichText.Type') == 'CodeMirror') {
+            return;
+        }
 
         function AutocompletionDataCallback(MatchInfo, Callback) {
             $.each(AutocompletionSettings.Triggers, function (Trigger) {
@@ -316,7 +320,7 @@ Core.UI.RichTextEditor = (function (TargetNS) {
             height:                    Core.Config.Get('RichText.Height', 320),
             removePlugins:             RemovedCKEditorPlugins,
             forcePasteAsPlainText:     false,
-            format_tags:               'p;h1;h2;h3;h4;h5;h6;pre',
+            format_tags:               Core.Config.Get('RichText.FormatTags', 'p;h1;h2;h3;h4;h5;h6;pre'),
             fontSize_sizes:            Core.Config.Get('RichText.FontSizes', '8px;10px;12px;14px;16px;18px;20px;22px;24px;26px;28px;30px;'),
             font_names:                Core.Config.Get('RichText.FontNames', ''),
             extraAllowedContent:       Core.Config.Get('RichText.ExtraAllowedContent', 'div[type]{*}; img[*]; col[width]; style[*]{*}; *[id](*)'),
